@@ -54,7 +54,7 @@ class Mobile_Base_Page(Borg, unittest.TestCase):
             self.exceptions = []
             self.test_env = ""          # pytest have Unresolved attribute reference if not added
             self.rp_logger = None
-            self.gif_file_name = None
+            self.gif_file_name = ""
             # self.tesults_flag = False
             # self.base64_flag = True
             self.reset()
